==> af-common-excel-2.0.8-sources.jar: com/af/v4/system/common/excel/controller/CRUDFormConfigController.java <==
package com.af.v4.system.common.excel.controller;

import com.af.v4.system.common.core.domain.R;
import com.af.v4.system.common.core.exception.LogicException;
import com.af.v4.system.common.excel.service.ExcelService;
import com.af.v4.system.common.jpa.service.EntityService;
import com.af.v4.system.common.liuli.config.service.LiuLiConfigService;
import com.af.v4.system.common.log.annotation.Log;
import com.af.v4.system.common.log.enums.BusinessType;
import com.af.v4.system.common.logic.service.LogicService;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Map;

/**
 * CRUD动态表单配置控制器
 *
 * @author Mr.river
 */
@RestController
@RequestMapping("/crud")
public class CRUDFormConfigController {

    private static final Logger LOGGER = LoggerFactory.getLogger(CRUDFormConfigController.class);

    private final EntityService entityService;

    private final LogicService logicService;

    private final LiuLiConfigService liuLiConfigService;

    public CRUDFormConfigController(EntityService entityService, LogicService logicService, LiuLiConfigService liuLiConfigService) {
        this.entityService = entityService;
        this.logicService = logicService;
        this.liuLiConfigService = liuLiConfigService;
    }

    /**
     * 通过excel导入数据
     *
     * @param file            二进制文件
     * @param queryParamsName 查询配置名称
     * @param userDataString  基本数据
     * @return 执行结果
     */
    @Log(title = "通过excel导入数据", businessType = BusinessType.IMPORT)
    @PostMapping(value = "/importDataByExcel", produces = MediaType.APPLICATION_JSON_VALUE)
    public R<Object> importDataByExcel(@RequestParam("file") MultipartFile file,
                                       @RequestParam("queryParamsName") String queryParamsName,
                                       @RequestParam(value = "userData", required = false) String userDataString) {
        try {
            JSONObject config = liuLiConfigService.get(queryParamsName, true);
            // 得到导入模板数据
            JSONArray excelImportTemplate = config.optJSONArray("excelImportTemplate");
            if (excelImportTemplate == null || excelImportTemplate.isEmpty()) {
                return R.fail("导入失败，没有配置导入列");
            }
            JSONObject apiSlot = config.optJSONObject("apiSlot");
            JSONArray titles = new JSONArray();
            JSONArray columns = new JSONArray();
            JSONObject userData = new JSONObject();
            if (userDataString != null && !userDataString.isEmpty()) {
                try {
                    userData = new JSONObject(userDataString);
                } catch (JSONException ignored) {
                    LOGGER.warn("操作人信息解析错误。");
                }
            }
            // 得到所有的标题和字段
            excelImportTemplate.forEach(item -> {
                JSONObject itemObj = ((JSONObject) item);
                titles.putAll(itemObj.get("title"));
                columns.putAll(itemObj.get("column"));
            });
            // 导入excel得到数据，数据是以下标为key，数据值为value的map集合
            List<Map<Integer, String>> dataList = ExcelService.importExcel(file.getInputStream(), titles);
            // 构建每行数据
            JSONArray datas = new JSONArray();
            dataList.forEach(data -> {
                JSONObject entity = new JSONObject();
                for (int i = 0; i < columns.length(); i++) {
                    entity.put(columns.getString(i), data.get(i));
                }
                datas.put(entity);
            });
            // 使用自定义校验 或者 自定义导入逻辑时 需要组织数据
            JSONObject SlotData = new JSONObject();
            if (apiSlot != null && !apiSlot.isEmpty()) {

                SlotData.put("config", config).put("datas", datas).put("userData", userData);
            }
            // 导入前插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateBefore")) {
                Object result = logicService.run(apiSlot.getString("excelImportTemplateBefore"), SlotData);
                JSONObject resultObj = (JSONObject) result;
                if (resultObj.get("status").toString().equals("1")) {
                    return R.fail(resultObj.optString("msg", "导入失败，数据校验失败"));
                }
            }
            // 是否配置了自定义导入逻辑插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateLogic")) {
                logicService.run(apiSlot.getString("excelImportTemplateLogic"), SlotData);
            } else {
                excelImportTemplate.forEach(importTable -> {
                    JSONObject importTableObj = ((JSONObject) importTable);
                    // 得到表名
                    String tableName = importTableObj.getString("tableName");
                    LOGGER.info("导入表名：{}", tableName);
                    // 批量保存数据
                    datas.forEach(data -> {
                        try {
                            entityService.partialSave(tableName, (JSONObject) data);
                        } catch (Exception e) {
                            throw new RuntimeException(e);
                        }
                    });
                });
            }
            // 导入后插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateAfter")) {
                logicService.run(apiSlot.getString("excelImportTemplateAfter"), SlotData);
            }
            return R.ok("导入数据成功");
        } catch (LogicException le) {
            LOGGER.error("导入数据失败：{}", le.getStack());
            return R.fail(le.getMessage());
        } catch (Exception e) {
            LOGGER.error("导入数据失败", e);
            return R.fail("导入数据失败");
        }
    }
}

==> af-common-excel-2.7.23-sources.jar: com/af/v4/system/common/excel/controller/CRUDFormConfigController.java <==
package com.af.v4.system.common.excel.controller;

import com.af.v4.system.common.core.domain.R;
import com.af.v4.system.common.core.exception.LogicException;
import com.af.v4.system.common.excel.service.ExcelService;
import com.af.v4.system.common.jpa.service.EntityService;
import com.af.v4.system.common.liuli.config.service.LiuLiConfigService;
import com.af.v4.system.common.log.annotation.Log;
import com.af.v4.system.common.log.enums.BusinessType;
import com.af.v4.system.common.logic.service.LogicService;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * CRUD动态表单配置控制器
 *
 * @author Mr.river
 */
@RestController
@RequestMapping("/crud")
public class CRUDFormConfigController {

    private static final Logger LOGGER = LoggerFactory.getLogger(CRUDFormConfigController.class);

    private final EntityService entityService;

    private final LogicService logicService;

    private final LiuLiConfigService liuLiConfigService;

    public CRUDFormConfigController(EntityService entityService, LogicService logicService, LiuLiConfigService liuLiConfigService) {
        this.entityService = entityService;
        this.logicService = logicService;
        this.liuLiConfigService = liuLiConfigService;
    }

    /**
     * 通过excel导入数据
     *
     * @param file            二进制文件
     * @param queryParamsName 查询配置名称
     * @param userDataString  基本数据
     * @return 执行结果
     */
    @Log(title = "通过excel导入数据", businessType = BusinessType.IMPORT)
    @PostMapping(value = "/importDataByExcel", produces = MediaType.APPLICATION_JSON_VALUE)
    public R<Object> importDataByExcel(@RequestParam("file") MultipartFile file,
                                       @RequestParam("queryParamsName") String queryParamsName,
                                       @RequestParam(value = "userData", required = false) String userDataString) {
        try {
            JSONObject config = liuLiConfigService.get(queryParamsName, true);
            JSONObject resultObj = new JSONObject();
            // 得到导入模板数据
            JSONArray excelImportTemplate = config.optJSONArray("excelImportTemplate");
            if (excelImportTemplate == null || excelImportTemplate.isEmpty()) {
                return R.fail("导入失败，没有配置导入列");
            }
            JSONObject apiSlot = config.optJSONObject("apiSlot");
            JSONArray titles = new JSONArray();
            JSONArray columns = new JSONArray();
            JSONObject userData = new JSONObject();
            if (userDataString != null && !userDataString.isEmpty()) {
                try {
                    userData = new JSONObject(userDataString);
                } catch (JSONException ignored) {
                    LOGGER.warn("操作人信息解析错误。");
                }
            }
            // 得到所有的标题和字段
            excelImportTemplate.forEach(item -> {
                JSONObject itemObj = ((JSONObject) item);
                titles.putAll(itemObj.get("title"));
                columns.putAll(itemObj.get("column"));
            });
            // 导入excel得到数据，数据是以下标为key，数据值为value的map集合
            List<Map<Integer, String>> dataList = ExcelService.importExcel(file.getInputStream(), titles);
            resultObj.put("successLen", dataList.size());
            // 构建每行数据
            JSONArray datas = new JSONArray();
            dataList.forEach(data -> {
                JSONObject entity = new JSONObject();
                for (int i = 0; i < columns.length(); i++) {
                    entity.put(columns.getString(i), data.get(i));
                }
                datas.put(entity);
            });
            // 使用自定义校验 或者 自定义导入逻辑时 需要组织数据
            JSONObject SlotData = new JSONObject();
            if (apiSlot != null && !apiSlot.isEmpty()) {
                SlotData.put("config", config).put("datas", datas).put("userData", userData);
            }
            // 导入前插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateBefore")) {
                Object result = logicService.run(apiSlot.getString("excelImportTemplateBefore"), SlotData);
                resultObj = (JSONObject) result;
                if (resultObj.get("status").toString().equals("1")) {
                    return R.fail(resultObj.optString("msg", "导入失败，数据校验失败"));
                }
            }
            // 是否配置了自定义导入逻辑插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateLogic")) {
                resultObj = new JSONObject(logicService.run(apiSlot.getString("excelImportTemplateLogic"), SlotData));
            } else {
                // 定义一个映射，用于存储要检查的字段及它们在finalUserData中的对应键名
                Map<String, String> fieldMapping = new HashMap<>();
                fieldMapping.put("f_orgid", "orgId");
                fieldMapping.put("f_orgname", "orgName");
                fieldMapping.put("f_depid", "depId");
                fieldMapping.put("f_depname", "depName");
                fieldMapping.put("f_operatorid", "currUserId");
                fieldMapping.put("f_operator", "currUserName");
                JSONObject finalUserData = userData;
                excelImportTemplate.forEach(importTable -> {
                    JSONObject importTableObj = ((JSONObject) importTable);
                    // 得到表名
                    String tableName = importTableObj.getString("tableName");
                    LOGGER.info("导入表名：{}", tableName);
                    // 批量保存数据
                    datas.forEach(data -> {
                        try {
                            JSONObject savaData = (JSONObject) data;
                            // 遍历映射，进行字段填充
                            for (Map.Entry<String, String> entry : fieldMapping.entrySet()) {
                                if (!savaData.has(entry.getKey())) {
                                    savaData.put(entry.getKey(), finalUserData.get(entry.getValue()));
                                }
                            }
                            entityService.partialSave(tableName, savaData);
                        } catch (Exception e) {
                            throw new RuntimeException(e);
                        }
                    });
                });
            }
            // 导入后插槽
            if (apiSlot != null && apiSlot.has("excelImportTemplateAfter")) {
                logicService.run(apiSlot.getString("excelImportTemplateAfter"), SlotData);
            }
            return R.ok(resultObj.toMap(), "导入数据成功");
        } catch (LogicException le) {
            LOGGER.error("导入数据失败：{}", le.getStack());
            return R.fail(le.getMessage());
        } catch (Exception e) {
            LOGGER.error("导入数据失败", e);
            return R.fail("导入数据失败");
        }
    }
}
